@@ -14,11 +14,9 @@ import botocore
 import botocore.session
 from botocore.exceptions import WaiterError
 
-from tests import unittest
-from tests import FileCreator
-from tests import random_bucket_name
 from s3transfer.manager import TransferManager
 from s3transfer.subscribers import BaseSubscriber
+from tests import FileCreator, random_bucket_name, unittest
 
 
 def recursive_delete(client, bucket_name):
@@ -37,7 +35,7 @@ def recursive_delete(client, bucket_name):
             break
         except client.exceptions.NoSuchBucket:
             exists_waiter.wait(Bucket=bucket_name)
-        except Exception as e:
+        except Exception:
             # We can sometimes get exceptions when trying to
             # delete a bucket.  We'll let the waiter make
             # the final call as to whether the bucket was able
@@ -60,7 +58,8 @@ class BaseTransferManagerIntegTest(unittest.TestCase):
         cls.bucket_name = random_bucket_name()
         cls.client.create_bucket(
             Bucket=cls.bucket_name,
-            CreateBucketConfiguration={'LocationConstraint': cls.region})
+            CreateBucketConfiguration={'LocationConstraint': cls.region},
+        )
 
     def setUp(self):
         self.files = FileCreator()
@@ -73,9 +72,7 @@ class BaseTransferManagerIntegTest(unittest.TestCase):
         recursive_delete(cls.client, cls.bucket_name)
 
     def delete_object(self, key):
-        self.client.delete_object(
-            Bucket=self.bucket_name,
-            Key=key)
+        self.client.delete_object(Bucket=self.bucket_name, Key=key)
 
     def object_exists(self, key, extra_args=None):
         try:
@@ -89,9 +86,7 @@ class BaseTransferManagerIntegTest(unittest.TestCase):
             extra_args = {}
         try:
             self.client.get_waiter('object_not_exists').wait(
-                Bucket=self.bucket_name,
-                Key=key,
-                **extra_args
+                Bucket=self.bucket_name, Key=key, **extra_args
             )
             return True
         except WaiterError:
@@ -102,9 +97,7 @@ class BaseTransferManagerIntegTest(unittest.TestCase):
             extra_args = {}
         for _ in range(5):
             self.client.get_waiter('object_exists').wait(
-                Bucket=self.bucket_name,
-                Key=key,
-                **extra_args
+                Bucket=self.bucket_name, Key=key, **extra_args
             )
 
     def create_transfer_manager(self, config=None):
