@@ -10,31 +10,39 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+import os
 import sys
 import time
 import traceback
-
-import mock
 from concurrent.futures import ThreadPoolExecutor
 
-from tests import unittest
-from tests import RecordingExecutor
-from tests import TransferCoordinatorWithInterrupt
-from s3transfer.exceptions import CancelledError
-from s3transfer.exceptions import FatalError
-from s3transfer.exceptions import TransferNotDoneError
-from s3transfer.futures import TransferFuture
-from s3transfer.futures import TransferMeta
-from s3transfer.futures import TransferCoordinator
-from s3transfer.futures import BoundedExecutor
-from s3transfer.futures import ExecutorFuture
-from s3transfer.futures import BaseExecutor
-from s3transfer.futures import NonThreadedExecutor
-from s3transfer.futures import NonThreadedExecutorFuture
+from s3transfer.exceptions import (
+    CancelledError,
+    FatalError,
+    TransferNotDoneError,
+)
+from s3transfer.futures import (
+    BaseExecutor,
+    BoundedExecutor,
+    ExecutorFuture,
+    NonThreadedExecutor,
+    NonThreadedExecutorFuture,
+    TransferCoordinator,
+    TransferFuture,
+    TransferMeta,
+)
 from s3transfer.tasks import Task
-from s3transfer.utils import FunctionContainer
-from s3transfer.utils import TaskSemaphore
-from s3transfer.utils import NoResourcesAvailable
+from s3transfer.utils import (
+    FunctionContainer,
+    NoResourcesAvailable,
+    TaskSemaphore,
+)
+from tests import (
+    RecordingExecutor,
+    TransferCoordinatorWithInterrupt,
+    mock,
+    unittest,
+)
 
 
 def return_call_args(*args, **kwargs):
@@ -48,18 +56,18 @@ def raise_exception(exception):
 def get_exc_info(exception):
     try:
         raise_exception(exception)
-    except:
+    except Exception:
         return sys.exc_info()
 
 
 class RecordingTransferCoordinator(TransferCoordinator):
     def __init__(self):
         self.all_transfer_futures_ever_associated = set()
-        super(RecordingTransferCoordinator, self).__init__()
+        super().__init__()
 
     def add_associated_future(self, future):
         self.all_transfer_futures_ever_associated.add(future)
-        super(RecordingTransferCoordinator, self).add_associated_future(future)
+        super().add_associated_future(future)
 
 
 class ReturnFooTask(Task):
@@ -135,7 +143,7 @@ class TestTransferFuture(unittest.TestCase):
         self.future.set_exception(ValueError())
         with self.assertRaises(ValueError):
             self.future.result()
-        
+
 
 class TestTransferMeta(unittest.TestCase):
     def setUp(self):
@@ -172,7 +180,8 @@ class TestTransferCoordinator(unittest.TestCase):
     def test_repr(self):
         transfer_coordinator = TransferCoordinator(transfer_id=1)
         self.assertEqual(
-            repr(transfer_coordinator), 'TransferCoordinator(transfer_id=1)')
+            repr(transfer_coordinator), 'TransferCoordinator(transfer_id=1)'
+        )
 
     def test_initial_status(self):
         # A TransferCoordinator with no progress should have the status
@@ -211,7 +220,7 @@ class TestTransferCoordinator(unittest.TestCase):
         self.transfer_coordinator.set_exception(exception_result)
         self.transfer_coordinator.announce_done()
         # Setting an exception should result in a failed state and the return
-        # value should be the rasied exception
+        # value should be the raised exception
         self.assertEqual(self.transfer_coordinator.status, 'failed')
         self.assertEqual(self.transfer_coordinator.exception, exception_result)
         with self.assertRaises(exception_result):
@@ -250,7 +259,8 @@ class TestTransferCoordinator(unittest.TestCase):
 
         self.assertEqual(self.transfer_coordinator.status, 'not-started')
         self.transfer_coordinator.add_done_callback(
-            capture_exception, self.transfer_coordinator, exceptions)
+            capture_exception, self.transfer_coordinator, exceptions
+        )
         self.transfer_coordinator.cancel()
 
         self.assertEqual(len(exceptions), 1)
@@ -260,21 +270,21 @@ class TestTransferCoordinator(unittest.TestCase):
         message = 'my message'
         self.transfer_coordinator.cancel(message)
         self.transfer_coordinator.announce_done()
-        with self.assertRaisesRegexp(CancelledError, message):
+        with self.assertRaisesRegex(CancelledError, message):
             self.transfer_coordinator.result()
 
     def test_cancel_with_provided_exception(self):
         message = 'my message'
         self.transfer_coordinator.cancel(message, exc_type=FatalError)
         self.transfer_coordinator.announce_done()
-        with self.assertRaisesRegexp(FatalError, message):
+        with self.assertRaisesRegex(FatalError, message):
             self.transfer_coordinator.result()
 
     def test_cancel_cannot_override_done_state(self):
         self.transfer_coordinator.set_result('foo')
         self.transfer_coordinator.cancel()
         # It status should be success even after cancel is called because
-        # succes is a done state.
+        # success is a done state.
         self.assertEqual(self.transfer_coordinator.status, 'success')
 
     def test_set_result_can_override_cancel(self):
@@ -289,7 +299,8 @@ class TestTransferCoordinator(unittest.TestCase):
         # Submit a callable to the transfer coordinator. It should submit it
         # to the executor.
         executor = RecordingExecutor(
-            BoundedExecutor(1, 1, {'my-tag': TaskSemaphore(1)}))
+            BoundedExecutor(1, 1, {'my-tag': TaskSemaphore(1)})
+        )
         task = ReturnFooTask(self.transfer_coordinator)
         future = self.transfer_coordinator.submit(executor, task, tag='my-tag')
         executor.shutdown()
@@ -297,7 +308,7 @@ class TestTransferCoordinator(unittest.TestCase):
         # result value which should include the provided future tag.
         self.assertEqual(
             executor.submissions,
-            [{'block': True, 'tag': 'my-tag', 'task': task}]
+            [{'block': True, 'tag': 'my-tag', 'task': task}],
         )
         self.assertEqual(future.result(), 'foo')
 
@@ -314,13 +325,12 @@ class TestTransferCoordinator(unittest.TestCase):
         # transfer future at some point.
         self.assertEqual(
             self.transfer_coordinator.all_transfer_futures_ever_associated,
-            set([future])
+            {future},
         )
 
         # Make sure the future got disassociated once the future is now done
         # by looking at the currently associated futures.
-        self.assertEqual(
-            self.transfer_coordinator.associated_futures, set([]))
+        self.assertEqual(self.transfer_coordinator.associated_futures, set())
 
     def test_done(self):
         # These should result in not done state:
@@ -354,8 +364,10 @@ class TestTransferCoordinator(unittest.TestCase):
 
         with ThreadPoolExecutor(max_workers=1) as executor:
             executor.submit(
-                sleep_then_set_result, self.transfer_coordinator,
-                execution_order)
+                sleep_then_set_result,
+                self.transfer_coordinator,
+                execution_order,
+            )
             self.transfer_coordinator.result()
             execution_order.append('after_result')
 
@@ -371,9 +383,11 @@ class TestTransferCoordinator(unittest.TestCase):
         second_kwargs = {'biz': 'baz'}
 
         self.transfer_coordinator.add_failure_cleanup(
-            return_call_args, *args, **kwargs)
+            return_call_args, *args, **kwargs
+        )
         self.transfer_coordinator.add_failure_cleanup(
-            return_call_args, *second_args, **second_kwargs)
+            return_call_args, *second_args, **second_kwargs
+        )
 
         # Ensure the callbacks got added.
         self.assertEqual(len(self.transfer_coordinator.failure_cleanups), 2)
@@ -383,7 +397,8 @@ class TestTransferCoordinator(unittest.TestCase):
         for cleanup in self.transfer_coordinator.failure_cleanups:
             result_list.append(cleanup())
         self.assertEqual(
-            result_list, [(args, kwargs), (second_args, second_kwargs)])
+            result_list, [(args, kwargs), (second_args, second_kwargs)]
+        )
 
     def test_associated_futures(self):
         first_future = object()
@@ -391,24 +406,26 @@ class TestTransferCoordinator(unittest.TestCase):
         self.transfer_coordinator.add_associated_future(first_future)
         associated_futures = self.transfer_coordinator.associated_futures
         # The first future should be in the returned list of futures.
-        self.assertEqual(associated_futures, set([first_future]))
+        self.assertEqual(associated_futures, {first_future})
 
         second_future = object()
         # Associate another future to the transfer.
         self.transfer_coordinator.add_associated_future(second_future)
         # The association should not have mutated the returned list from
         # before.
-        self.assertEqual(associated_futures, set([first_future]))
+        self.assertEqual(associated_futures, {first_future})
 
         # Both futures should be in the returned list.
         self.assertEqual(
             self.transfer_coordinator.associated_futures,
-            set([first_future, second_future]))
+            {first_future, second_future},
+        )
 
     def test_done_callbacks_on_done(self):
         done_callback_invocations = []
         callback = FunctionContainer(
-            done_callback_invocations.append, 'done callback called')
+            done_callback_invocations.append, 'done callback called'
+        )
 
         # Add the done callback to the transfer.
         self.transfer_coordinator.add_done_callback(callback)
@@ -427,7 +444,8 @@ class TestTransferCoordinator(unittest.TestCase):
     def test_failure_cleanups_on_done(self):
         cleanup_invocations = []
         callback = FunctionContainer(
-            cleanup_invocations.append, 'cleanup called')
+            cleanup_invocations.append, 'cleanup called'
+        )
 
         # Add the failure cleanup to the transfer.
         self.transfer_coordinator.add_failure_cleanup(callback)
@@ -471,7 +489,7 @@ class TestBoundedExecutor(unittest.TestCase):
             self.executor.submit(task, tag=tag, block=False)
         except NoResourcesAvailable:
             self.fail(
-                'Task %s should not have been blocked. Caused by:\n%s' % (
+                'Task {} should not have been blocked. Caused by:\n{}'.format(
                     task, traceback.format_exc()
                 )
             )
@@ -490,6 +508,10 @@ class TestBoundedExecutor(unittest.TestCase):
         # Ensure the callable got executed.
         self.assertEqual(future.result(), 'foo')
 
+    @unittest.skipIf(
+        os.environ.get('USE_SERIAL_EXECUTOR'),
+        "Not supported with serial executor tests",
+    )
     def test_executor_blocks_on_full_capacity(self):
         first_task = self.get_sleep_task()
         second_task = self.get_sleep_task()
@@ -511,11 +533,16 @@ class TestBoundedExecutor(unittest.TestCase):
         # blocked because the first task should have finished clearing up
         # capacity.
         self.add_done_callback_to_future(
-            future, self.assert_submit_would_not_block, second_task)
+            future, self.assert_submit_would_not_block, second_task
+        )
 
         # Wait for it to complete.
         self.executor.shutdown()
 
+    @unittest.skipIf(
+        os.environ.get('USE_SERIAL_EXECUTOR'),
+        "Not supported with serial executor tests",
+    )
     def test_would_not_block_when_full_capacity_in_other_semaphore(self):
         first_task = self.get_sleep_task()
 
@@ -544,6 +571,10 @@ class TestBoundedExecutor(unittest.TestCase):
         # Ensure that the shutdown waits until the task is done
         self.assertTrue(future.done())
 
+    @unittest.skipIf(
+        os.environ.get('USE_SERIAL_EXECUTOR'),
+        "Not supported with serial executor tests",
+    )
     def test_shutdown_no_wait(self):
         slow_task = self.get_sleep_task()
         future = self.executor.submit(slow_task)
@@ -578,7 +609,8 @@ class TestExecutorFuture(unittest.TestCase):
             future = executor.submit(return_call_args, 'foo', biz='baz')
             wrapped_future = ExecutorFuture(future)
             wrapped_future.add_done_callback(
-                FunctionContainer(done_callbacks.append, 'called'))
+                FunctionContainer(done_callbacks.append, 'called')
+            )
         self.assertEqual(done_callbacks, ['called'])
 
 
@@ -633,7 +665,7 @@ class TestNonThreadedExecutorFuture(unittest.TestCase):
     def test_exception_result(self):
         exception = ValueError('message')
         self.future.set_exception_info(exception, None)
-        with self.assertRaisesRegexp(ValueError, 'message'):
+        with self.assertRaisesRegex(ValueError, 'message'):
             self.future.result()
 
     def test_exception_result_doesnt_modify_last_frame(self):
